@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from Acquisition import aq_base
+from HTMLParser import HTMLParser
 from DateTime import DateTime
 from plone import api
 from plone.app.portlets.interfaces import IPortletTypeInterface
@@ -12,7 +13,7 @@ from six.moves import range
 from zope.component import getUtilitiesFor
 from zope.component import queryMultiAdapter
 from zope.interface import providedBy
-
+from .migration.topics import TopicMigrator
 
 import datetime
 import lxml
@@ -337,7 +338,8 @@ class Wrapper(dict):
                         value = self.decode(value)
 
                 if value and type_ in ["StringField", "TextField"]:
-                    if type_ == "TextField":
+                    widget_class = field.widget.__class__.__name__
+                    if type_ == "TextField" and widget_class == "RichWidget":
                         value = self.fix_links(html=value)
                     try:
                         value = self.decode(value)
@@ -476,6 +478,41 @@ class Wrapper(dict):
                     value = self._get_at_field_value(field)
                 self[six.text_type(fieldname)] = self.decode(str(value))
 
+        if self.context.portal_type == "Topic":
+            mt = TopicMigrator()
+            criterions_list = mt.__call__(self.context)
+            # check format in case of date values
+            for crit_dict in criterions_list:
+                values = crit_dict.get("v")
+                if not values:
+                    continue
+                if isinstance(values, int):
+                    continue
+                if not any(
+                    [True for x in values if isinstance(x, DateTime)]
+                ):  # noqa
+                    continue
+
+                new_values = []
+
+                for val in values:
+                    new_values.append(val.asdatetime().isoformat())
+                if isinstance(values, tuple):
+                    new_values = tuple(new_values)
+                crit_dict.update({"v": new_values})
+
+            sort_on = mt._collection_sort_on
+            sort_reversed = mt._collection_sort_reversed
+
+            self["query"] = criterions_list
+            self["sort_on"] = sort_on
+            self["sort_reversed"] = sort_reversed
+
+            if not self.get("itemCount"):
+                self["item_count"] = "30"
+            else:
+                self["item_count"] = data.get("itemCount")
+
     def get_references(self):
         """AT references.
         """
@@ -1102,7 +1139,7 @@ class Wrapper(dict):
     def fix_links(self, html):
         if not html:
             return ""
-        root = lxml.html.fromstring(html)
+        root = lxml.html.fromstring(html.decode("utf-8"))
         for link in root.xpath("//a"):
             href = link.get("href", "")
             if not href:
@@ -1122,6 +1159,11 @@ class Wrapper(dict):
             item = api.content.get(path)
             if not item:
                 continue
-            href = "resolveuid/{}".format(IUUID(item))
-            link.set("href", href)
-        return safe_unicode(lxml.html.tostring(root))
+            try:
+                href = "resolveuid/{}".format(IUUID(item))
+                link.set("href", href)
+            except TypeError:
+                continue
+        return HTMLParser.unescape.__func__(
+            HTMLParser, safe_unicode(lxml.html.tostring(root))
+        )
